coef.gaussian: Extract Coefficients from an Object with S3 Class...

View source: R/picasso.gaussian.R

coef.gaussianR Documentation

Extract Coefficients from an Object with S3 Class "gaussian"

Description

Extract estimated coefficient vectors from selected points on the regularization path.

Usage

## S3 method for class 'gaussian'
coef(object, lambda.idx = c(1:3), beta.idx = c(1:3), ...)

Arguments

object

An object with S3 class "gaussian".

lambda.idx

Indices of regularization parameters in the solution path to extract. The default is c(1:3).

beta.idx

Indices of coefficient entries to extract. The default is c(1:3).

...

Arguments to be passed to methods.

Value

A numeric matrix of extracted coefficients. Columns correspond to lambda.idx. Rows contain the intercept ("(Intercept)") and the selected coefficients ("beta[i]" for i in beta.idx).

Author(s)

Jason Ge, Xingguo Li, Haoming Jiang, Mengdi Wang, Tong Zhang, Han Liu and Tuo Zhao
Maintainer: Tuo Zhao <tourzhao@gatech.edu>

See Also

picasso and picasso-package.


picasso documentation built on March 12, 2026, 5:06 p.m.