View source: R/picasso.logit.R
| coef.logit | R Documentation |
"logit"
Extract estimated coefficient vectors from selected points on the regularization path.
## S3 method for class 'logit'
coef(object, lambda.idx = c(1:3), beta.idx = c(1:3), ...)
object |
An object with S3 class |
lambda.idx |
Indices of regularization parameters in the solution path to extract.
The default is |
beta.idx |
Indices of coefficient entries to extract. The default is |
... |
Arguments to be passed to methods. |
A numeric matrix of extracted coefficients.
Columns correspond to lambda.idx. Rows contain the intercept
("(Intercept)") and the selected coefficients
("beta[i]" for i in beta.idx).
Jason Ge, Xingguo Li, Haoming Jiang, Mengdi Wang, Tong Zhang, Han Liu and Tuo Zhao
Maintainer: Tuo Zhao <tourzhao@gatech.edu>
picasso and picasso-package.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.