View source: R/picasso.gaussian.R
| predict.gaussian | R Documentation |
"gaussian"
Predict responses for new data using fitted models.
## S3 method for class 'gaussian'
predict(object, newdata, lambda.idx = c(1:3), Y.pred.idx = c(1:5), ...)
object |
An object with S3 class |
newdata |
Optional matrix/data frame used for prediction. If omitted, the training design matrix from fitting is used. |
lambda.idx |
Indices of regularization parameters along the solution path used for prediction.
The default is |
Y.pred.idx |
Optional row indices to subset returned predictions when explicitly set to a
value different from the default |
... |
Arguments to be passed to methods. |
predict.gaussian returns predicted responses for newdata using fitted coefficients from object:
\hat{Y} = \hat{\beta}_0 + X_{new} \hat{\beta}.
Numeric matrix of predicted responses. Rows correspond to observations in
newdata; columns correspond to lambda.idx.
Jason Ge, Xingguo Li, Haoming Jiang, Mengdi Wang, Tong Zhang, Han Liu and Tuo Zhao
Maintainer: Tuo Zhao <tourzhao@gatech.edu>
picasso and picasso-package.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.