predict.sqrtlasso: Prediction Method for an Object with S3 Class '"sqrtlasso"'

View source: R/picasso.sqrtlasso.R

predict.sqrtlassoR Documentation

Prediction Method for an Object with S3 Class "sqrtlasso"

Description

Predict responses for new data using fitted models.

Usage

## S3 method for class 'sqrtlasso'
predict(object, newdata, lambda.idx = c(1:3), Y.pred.idx = c(1:5), ...)

Arguments

object

An object with S3 class "sqrtlasso".

newdata

Optional matrix/data frame used for prediction. If omitted, the training design matrix from fitting is used.

lambda.idx

Indices of regularization parameters along the solution path used for prediction. The default is c(1:3).

Y.pred.idx

Optional row indices to subset returned predictions when explicitly set to a value different from the default c(1:5).

...

Arguments to be passed to methods.

Details

predict.sqrtlasso returns predicted responses for newdata using fitted coefficients from object:

\hat{Y} = \hat{\beta}_0 + X_{new} \hat{\beta}.


Value

Numeric matrix of predicted responses. Rows correspond to observations in newdata; columns correspond to lambda.idx.

Author(s)

Jason Ge, Xingguo Li, Haoming Jiang, Mengdi Wang, Tong Zhang, Han Liu and Tuo Zhao
Maintainer: Tuo Zhao <tourzhao@gatech.edu>

See Also

picasso and picasso-package.


picasso documentation built on March 12, 2026, 5:06 p.m.