print.poisson: Print Method for an Object with S3 Class '"poisson"'

View source: R/picasso.poisson.R

print.poissonR Documentation

Print Method for an Object with S3 Class "poisson"

Description

Print a concise summary for an object with S3 class "poisson".

Usage

## S3 method for class 'poisson'
print(x, ...)

Arguments

x

An object with S3 class "poisson".

...

Arguments to be passed to methods.

Details

This method prints tuning parameters and fit statistics for a fitted Poisson model object.

Value

The input object x, returned invisibly.

Author(s)

Jason Ge, Xingguo Li, Haoming Jiang, Mengdi Wang, Tong Zhang, Han Liu and Tuo Zhao
Maintainer: Tuo Zhao <tourzhao@gatech.edu>

See Also

picasso and picasso-package.


picasso documentation built on March 12, 2026, 5:06 p.m.