View source: R/picasso.sqrtlasso.R
| print.sqrtlasso | R Documentation |
"sqrtlasso"
Print a concise summary for an object with S3 class "sqrtlasso".
## S3 method for class 'sqrtlasso'
print(x, ...)
x |
An object with S3 class |
... |
Arguments to be passed to methods. |
This method prints tuning parameters and fit statistics for a fitted model object.
The input object x, returned invisibly.
Jason Ge, Xingguo Li, Haoming Jiang, Mengdi Wang, Tong Zhang, Han Liu and Tuo Zhao
Maintainer: Tuo Zhao <tourzhao@gatech.edu>
picasso and picasso-package.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.