Learn R Programming

picasso (version 2.0.1)

coef.logit: Extract Coefficients from an Object with S3 Class "logit"

Description

Extract estimated coefficient vectors from selected points on the regularization path.

Usage

# S3 method for logit
coef(object, lambda.idx = NULL, beta.idx = NULL, ...)

Value

A numeric matrix of extracted coefficients. Columns correspond to lambda.idx. Rows contain the intercept ("(Intercept)") and the selected coefficients ("beta[i]" for i in beta.idx).

Arguments

object

An object with S3 class "logit".

lambda.idx

Indices of regularization parameters in the solution path to extract. By default, at most the first three fitted path points are used.

beta.idx

Indices of coefficient entries to extract. By default, at most the first three coefficients are used.

...

Arguments to be passed to methods.

Author

Jason Ge, Xingguo Li, Haoming Jiang, Mengdi Wang, Tong Zhang, Han Liu and Tuo Zhao
Maintainer: Tuo Zhao <tourzhao@gatech.edu>

See Also

picasso and picasso-package.