"poisson"Extract estimated coefficient vectors from selected points on the regularization path.
# S3 method for poisson
coef(object, lambda.idx = c(1:3), beta.idx = c(1:3), ...)A numeric matrix of extracted coefficients.
Columns correspond to lambda.idx. Rows contain the intercept
("(Intercept)") and the selected coefficients
("beta[i]" for i in beta.idx).
An object with S3 class "poisson".
Indices of regularization parameters in the solution path to extract.
The default is c(1:3).
Indices of coefficient entries to extract. The default is c(1:3).
Arguments to be passed to methods.
Jason Ge, Xingguo Li, Haoming Jiang, Mengdi Wang, Tong Zhang, Han Liu and Tuo Zhao
Maintainer: Tuo Zhao <tourzhao@gatech.edu>
picasso and picasso-package.