| eyedata | R Documentation |
Gene expression data (200 genes, 120 samples) from microarray experiments on mammalian eye tissue reported by Scheetz et al. (2006).
data(eyedata)
A list with components:
A 120 by 200 matrix of gene probes.
A numeric response vector of length 120 representing the expression level of the TRIM32 gene.
This data set contains 120 samples and 200 predictors.
Xingguo Li, Tuo Zhao, Tong Zhang and Han Liu
Maintainer: Tuo Zhao <tourzhao@gatech.edu>
1. T. Scheetz, K. Kim, R. Swiderski, A. Philp, T. Braun, K. Knudtson, A. Dorrance, G. DiBona, J. Huang, T. Casavant, V. Sheffield, and E. Stone. Regulation of gene expression in the mammalian eye and its relevance to eye disease. Proceedings of the National Academy of Sciences of the United States of America, 2006.
picasso-package.
data(eyedata)
image(eyedata$x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.