Learn R Programming

picasso (version 1.5)

eyedata: Bardet-Biedl Syndrome Gene Expression Data from Scheetz et al. (2006)

Description

Gene expression data (200 genes, 120 samples) from microarray experiments on mammalian eye tissue reported by Scheetz et al. (2006).

Usage

data(eyedata)

Arguments

Format

A list with components:

x

A 120 by 200 matrix of gene probes.

y

A numeric response vector of length 120 representing the expression level of the TRIM32 gene.

Author

Xingguo Li, Tuo Zhao, Tong Zhang and Han Liu
Maintainer: Tuo Zhao <tourzhao@gatech.edu>

Details

This data set contains 120 samples and 200 predictors.

References

1. T. Scheetz, K. Kim, R. Swiderski, A. Philp, T. Braun, K. Knudtson, A. Dorrance, G. DiBona, J. Huang, T. Casavant, V. Sheffield, and E. Stone. Regulation of gene expression in the mammalian eye and its relevance to eye disease. Proceedings of the National Academy of Sciences of the United States of America, 2006.

See Also

picasso-package.

Examples

Run this code
data(eyedata)
image(eyedata$x)

Run the code above in your browser using DataLab