"sqrtlasso"Predict responses for new data using fitted models.
# S3 method for sqrtlasso
predict(object, newdata, lambda.idx = c(1:3), Y.pred.idx = c(1:5), ...)Numeric matrix of predicted responses. Rows correspond to observations in
newdata; columns correspond to lambda.idx.
An object with S3 class "sqrtlasso".
Optional matrix/data frame used for prediction. If omitted, the training design matrix from fitting is used.
Indices of regularization parameters along the solution path used for prediction.
The default is c(1:3).
Optional row indices to subset returned predictions when explicitly set to a
value different from the default c(1:5).
Arguments to be passed to methods.
Jason Ge, Xingguo Li, Haoming Jiang, Mengdi Wang, Tong Zhang, Han Liu and Tuo Zhao
Maintainer: Tuo Zhao <tourzhao@gatech.edu>
predict.sqrtlasso returns predicted responses for newdata using fitted coefficients from object:
$$
\hat{Y} = \hat{\beta}_0 + X_{new} \hat{\beta}.
$$
picasso and picasso-package.