Learn R Programming

picasso (version 1.5)

print.logit: Print Method for an Object with S3 Class "logit"

Description

Print a concise summary for an object with S3 class "logit".

Usage

# S3 method for logit
print(x, ...)

Value

The input object x, returned invisibly.

Arguments

x

An object with S3 class "logit".

...

Arguments to be passed to methods.

Author

Jason Ge, Xingguo Li, Haoming Jiang, Mengdi Wang, Tong Zhang, Han Liu and Tuo Zhao
Maintainer: Tuo Zhao <tourzhao@gatech.edu>

Details

This method prints tuning parameters and fit statistics for a fitted logistic model object.

See Also

picasso and picasso-package.