View source: R/picasso.poisson.R
| print.poisson | R Documentation |
"poisson"
Print a concise summary for an object with S3 class "poisson".
## S3 method for class 'poisson'
print(x, ...)
x |
An object with S3 class |
... |
Arguments to be passed to methods. |
This method prints tuning parameters and fit statistics for a fitted Poisson model object.
The input object x, returned invisibly.
Jason Ge, Xingguo Li, Haoming Jiang, Mengdi Wang, Tong Zhang, Han Liu and Tuo Zhao
Maintainer: Tuo Zhao <tourzhao@gatech.edu>
picasso and picasso-package.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.