powered by
"poisson"
Print a concise summary for an object with S3 class "poisson".
# S3 method for poisson print(x, ...)
The input object x, returned invisibly.
x
An object with S3 class "poisson".
Arguments to be passed to methods.
Jason Ge, Xingguo Li, Haoming Jiang, Mengdi Wang, Tong Zhang, Han Liu and Tuo Zhao Maintainer: Tuo Zhao <tourzhao@gatech.edu>
This method prints tuning parameters and fit statistics for a fitted Poisson model object.
picasso and picasso-package.
picasso
picasso-package